@@ -15,6 +15,8 @@ __docformat__ = 'epytext'
 __copyright__ = "2010 Twinapex Research"
 __license__ = "GPL v2"
 
+
+
 def getView(context, name):
     """ Get Zope 2 view with acquisition chain properly set up.
 
@@ -54,4 +56,29 @@ def queryView(context, name):
 
     view = view.__of__(context)
 
-    return view
\ No newline at end of file
+    return view
+
+
+from zope.component import getMultiAdapter
+
+def getSiteRootRelativePath(context, request):
+    """ Get site root relative path to an item
+    
+    @param context: Content item which path is resolved
+    
+    @param request: HTTP request object
+    
+    @return: Path to the context object, relative to site root, prefixed with a slash.
+    """
+    
+    portal_state = getMultiAdapter((context, request), name=u'plone_portal_state')
+    site = portal_state.portal()
+    
+    # Both of these are tuples 
+    site_path = site.getPhysicalPath();
+    context_path = context.getPhysicalPath()
+    
+    relative_path = context_path[len(site_path)+1:]
+    
+    return "/" + "/".join(relative_path)
+    
\ No newline at end of file
